CREATE SCHEMA Bauwerke

-- Historie:
--
-- 31.05.2002 - 1.003 (1.007)
-- berarbeitung gem Dokument N0031
--
-- 12.09.2001 - 1.002 (1.004)
-- nderung berlanger Bezeichner Strassenbaudienstst_abstr
-- in Strassenbaudienststelle_abstr
--
-- 17.12.2000 - 1.001 (1.002)
-- Integration symbolischer Verweise fr
-- Bauwerk, Teilbauwerk und Strassenbaudienststelle
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Bauwerk (
   Bauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bauwerk_ID) REFERENCES Bauwerk_abstrakt,
   Bauwerksnummer
      VARCHAR(7) NOT NULL,
   Interne_Bauwerksnummer
      VARCHAR(12),
   Interner_Sortierschluessel
      VARCHAR(15),
   Bauwerksname
      VARCHAR(50),
   naechstgelegener_Ort
      VARCHAR(50),
   Bemerkungen
      VARCHAR(255),
   hat_Amt
      INTEGER REFERENCES Administration.Strassenbaudienstst_abstr,
   hat_Verwaltungsbezirk
      INTEGER REFERENCES Administration.Verwaltungsbezirk_abstrakt
)

CREATE TABLE Bauwerk__besteht_aus_Teilbauw (
   Bauwerk
      INTEGER NOT NULL REFERENCES Bauwerk,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Bauwerk_abstrakt (
   Bauwerk_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Bauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Art_Bauwerk_abstrakt
)

CREATE TABLE Art_Bauwerk_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(14) NOT NULL
)

INSERT INTO Art_Bauwerk_abstrakt VALUES (1,'Bauwerk')
INSERT INTO Art_Bauwerk_abstrakt VALUES (2,'Bauwerk_Symbol')

CREATE TABLE Bauwerk_Symbol (
   Bauwerk_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bauwerk_Symbol_ID) REFERENCES Bauwerk_abstrakt,
   Kennung
      CHAR(7) NOT NULL
)

CREATE TABLE Teilbauwerk (
   Teilbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Teilbauwerk_ID) REFERENCES Strassennetz.Punktobjekt_hist,
   FOREIGN KEY (Teilbauwerk_ID) REFERENCES Teilbauwerk_abstrakt,
   FOREIGN KEY (Teilbauwerk_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   Teilbauwerksnummer
      VARCHAR(2) NOT NULL,
   Name_des_Teilbauwerks
      VARCHAR(50),
   Interner_Sortierschluessel
      VARCHAR(15),
   Unterhaltung_Instandsetzung
      VARCHAR(15),
   Bauwerksart
      VARCHAR(15),
   Stadium_Teilbauwerk
      VARCHAR(15),
   Bauwerksakte_Nummer
      VARCHAR(50),
   Baulast_Konstruktion
      VARCHAR(15),
   Baujahr
      INTEGER, -- Jahr
   Denkmalschutz
      VARCHAR(50),
   Unterlagen
      VARCHAR(255),
   Datenerfassung_abgeschlossen
      VARCHAR(15),
   Konstruktion
      VARCHAR(50),
   Bauwerksrichtung
      VARCHAR(15),
   Bauwerksrichtung_Text
      VARCHAR(255),
   Bemerkungen
      VARCHAR(255),
   hat_Bauwerkseinzelheiten
      INTEGER NOT NULL REFERENCES Ingenieurbauwerke.Bauwerkseinzelheiten,
   gehoert_zu_Bauwerk
      INTEGER NOT NULL REFERENCES Bauwerk_abstrakt
)

CREATE TABLE Teilbw__hat_Strbaudienststelle (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Strassenbaudienstst_abstr
      INTEGER NOT NULL REFERENCES Administration.Strassenbaudienstst_abstr
)

CREATE TABLE Teilbauwerk__hat_Sachverhalt (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Sachverhalt
      INTEGER NOT NULL REFERENCES Sachverhalt
)

CREATE TABLE Teilbw__hat_Schadensd_abg_Prfg (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Schadensdaten_abgeschl_Prfg
      INTEGER NOT NULL REFERENCES Schadensdaten_abgeschl_Prfg
)

CREATE TABLE Teilbw__hat_Pruefgsd_abg_Prfg (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Pruefungsdaten_abgeschl_Prfg
      INTEGER NOT NULL REFERENCES Pruefungsdaten_abgeschl_Prfg
)

CREATE TABLE Teilbw__hat_gegw_dok_Schadstd (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   gegenw_dokum_Schadensstand
      INTEGER NOT NULL REFERENCES gegenw_dokum_Schadensstand
)

CREATE TABLE Teilbw__hat_gegw_dok_Pruefstd (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   gegenw_dokum_Pruefungsstand
      INTEGER NOT NULL REFERENCES gegenw_dokum_Pruefungsstand
)

CREATE TABLE Teilbw__hat_durchgef_Prf_Mess (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   durchgef_Pruefungen_Messungen
      INTEGER NOT NULL REFERENCES durchgef_Pruefungen_Messungen
)

CREATE TABLE Teilbw__hat_Prueffz_Pruefger (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Prueffahrzeuge_Pruefgeraete
      INTEGER NOT NULL REFERENCES Prueffahrzeuge_Pruefgeraete
)

CREATE TABLE Teilbw__hat_Pruefanweisungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Pruefanweisungen
      INTEGER NOT NULL REFERENCES Pruefanweisungen
)

CREATE TABLE Teilbw__hat_Verwaltungsmassn (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Verwaltungsmassn_Sondervereinb
      INTEGER NOT NULL REFERENCES Verwaltungsmassn_Sondervereinb
)

CREATE TABLE Teilbw__hat_Bau_u_Erhaltmassn (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Bau_und_Erhaltungsmassnahme
      INTEGER NOT NULL REFERENCES Bau_und_Erhaltungsmassnahme
)

CREATE TABLE Teilbw__hat_Anlagen_Bauwbuch (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Anlagen_Bauwerksbuch
      INTEGER NOT NULL REFERENCES Anlagen_Bauwerksbuch
)

CREATE TABLE Teilbw__hat_Entwue_und_Berechn (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Entwuerfe_und_Berechnungen
      INTEGER NOT NULL REFERENCES Entwuerfe_und_Berechnungen
)

CREATE TABLE Teilbauwerk__hat_Gestaltungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Gestaltungen
      INTEGER NOT NULL REFERENCES Gestaltungen
)

CREATE TABLE Teilbw__hat_Leitungen_an_Bauw (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Leitungen_an_Bauwerken
      INTEGER NOT NULL REFERENCES Leitungen_an_Bauwerken
)

CREATE TABLE Teilbw__hat_stat_System_Tragf (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   statisches_System_Tragfaehigkt
      INTEGER NOT NULL REFERENCES statisches_System_Tragfaehigkt
)

CREATE TABLE Teilbauwerk__hat_Vorspannungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Vorspannungen
      INTEGER NOT NULL REFERENCES Vorspannungen
)

CREATE TABLE Teilbauwerk__hat_Gruendungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Gruendungen
      INTEGER NOT NULL REFERENCES Gruendungen
)

CREATE TABLE Teilbw__hat_Erd_und_Felsanker (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Erd_und_Felsanker
      INTEGER NOT NULL REFERENCES Erd_und_Felsanker
)

CREATE TABLE Teilbw__hat_Brueckseil_u_Kabel (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Brueckenseile_und_kabel
      INTEGER NOT NULL REFERENCES Brueckenseile_und_kabel
)

CREATE TABLE Teilbw__hat_Fahrbuebergkonstr (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Fahrbahnuebergangskonstruktion
      INTEGER NOT NULL REFERENCES Fahrbahnuebergangskonstruktion
)

CREATE TABLE Teilbauwerk__hat_Abdichtungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Abdichtungen
      INTEGER NOT NULL REFERENCES Abdichtungen
)

CREATE TABLE Teilbauwerk__hat_Kappe (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Kappe
      INTEGER NOT NULL REFERENCES Kappe
)

CREATE TABLE Teilbw__hat_Schutzeinrichtgen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Schutzeinrichtungen
      INTEGER NOT NULL REFERENCES Schutzeinrichtungen
)

CREATE TABLE Teilbauwerk__hat_Ausstattung (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Ausstattung
      INTEGER NOT NULL REFERENCES Ausstattung
)

CREATE TABLE Teilbauwerk__hat_Verfuellungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Verfuellungen
      INTEGER NOT NULL REFERENCES Verfuellungen
)

CREATE TABLE Teilbw__hat_Betonersatz (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Betonersatz_nach_ZTV_SIB
      INTEGER NOT NULL REFERENCES Betonersatz_nach_ZTV_SIB
)

CREATE TABLE Teilbw__hat_Oberflaechenschutz (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Oberflschutz_nach_ZTV_SIB
      INTEGER NOT NULL REFERENCES Oberflschutz_nach_ZTV_SIB
)

CREATE TABLE Teilbw__hat_Reaktharzg_Duennb (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Reaktionsharzgeb_Duennbelaege
      INTEGER NOT NULL REFERENCES Reaktionsharzgeb_Duennbelaege
)

CREATE TABLE Teilbauwerk__von_Hindernis (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Hindernis
      INTEGER NOT NULL REFERENCES Bauliche_Strasseneigenschaften.Hindernis
)

CREATE TABLE Teilbauwerk__von_Kreuzung (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Kreuzung_Strasse_Weg
      INTEGER NOT NULL REFERENCES Bauliche_Strasseneigenschaften.Kreuzung_Strasse_Weg
)

CREATE TABLE Teilbauwerk_abstrakt (
   Teilbauwerk_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Art_Teilbauwerk_abstrakt
)

CREATE TABLE Art_Teilbauwerk_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(22) NOT NULL
)

INSERT INTO Art_Teilbauwerk_abstrakt VALUES (1,'Teilbauwerk')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (2,'Bruecke')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (3,'Verkehrszeichenbruecke')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (4,'Tunnel_Trogbauwerk')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (5,'Laermschutzbauwerk')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (6,'Stuetzbauwerk')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (7,'sonstiges_Bauwerk')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (8,'Teilbauwerk_Symbol')

CREATE TABLE Teilbauwerk_Symbol (
   Teilbauwerk_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Teilbauwerk_Symbol_ID) REFERENCES Teilbauwerk_abstrakt,
   Kennung
      CHAR(9) NOT NULL
)

CREATE TABLE Bauwerk_Netzzuordnung (
   Bauwerk_Netzzuordnung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bauwerk_Netzzuordnung_ID) REFERENCES Strassennetz.Punktobjekt_stat,
   FOREIGN KEY (Bauwerk_Netzzuordnung_ID) REFERENCES Strassennetz.Streckenobjekt_stat,
   Laufende_Nummer
      INTEGER NOT NULL,
   Strassenname
      VARCHAR(80) NOT NULL,
   Abschnittsnummer
      VARCHAR(4) NOT NULL,
   Weiterlauf
      VARCHAR(15),
   Bemerkung
      VARCHAR(255) NOT NULL,
   hat_Kilometrierung
      INTEGER REFERENCES Strassennetz.Kilometrierung,
   hat_Anzahl_Fahrstreifen
      INTEGER REFERENCES Verkehr.Anzahl_Fahrstreifen,
   hat_UI_Vereinbarung
      INTEGER REFERENCES Administration.UI_Vereinbarung,
   von_Sachverhalt
      INTEGER NOT NULL REFERENCES Sachverhalt
)

CREATE TABLE Sachverhalt (
   Sachverhalt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Lage_Sachverhalt
      VARCHAR(15),
   Art_des_Sachverhaltes
      VARCHAR(15),
   Name_des_Sachverhaltes
      VARCHAR(255),
   Strassenklasse_des_Sachverh
      CHAR(6),
   Strassennummer_des_Sachverh
      INTEGER,
   Strassenzusatz
      CHAR(1),
   Unterhaltungszuordnung
      INTEGER REFERENCES Logical_Types.Boolean,
   hat_Routing
      INTEGER REFERENCES Routing
)

CREATE TABLE Sachverhalt__hat_Bauwerksbel (
   Sachverhalt
      INTEGER NOT NULL REFERENCES Sachverhalt,
   Bauwerksbelaege
      INTEGER NOT NULL REFERENCES Bauwerksbelaege
)

CREATE TABLE Sachverhalt__hat_Bauwerksbesch (
   Sachverhalt
      INTEGER NOT NULL REFERENCES Sachverhalt,
   Bauwerksbeschilderung
      INTEGER NOT NULL REFERENCES Bauwerksbeschilderung
)

CREATE TABLE Sachverhalt__von_Teilbauwerk (
   Sachverhalt
      INTEGER NOT NULL REFERENCES Sachverhalt,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Routing (
   Routing_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Min_Breite_in_Stationierung
      REAL, -- Meter
   Min_Breite_gegen_Stationierung
      REAL, -- Meter
   Routing_1
      VARCHAR(50),
   Routing_2
      VARCHAR(50),
   Umfahrt_Schwerverkehr
      VARCHAR(15),
   Umfahrt_OePNV
      VARCHAR(15),
   Umfahrt_PKW
      VARCHAR(15),
   Bemerkung
      VARCHAR(255),
   hat_Amt
      INTEGER REFERENCES Administration.Strassenbaudienstst_abstr,
   hat_Meisterei
      INTEGER REFERENCES Administration.Strassenbaudienstst_abstr
)

CREATE TABLE Durchfahrtshoehen (
   Durchfahrtshoehen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Abstand_Bestandsachse
      REAL, -- Meter
   Durchfahrtshoehe
      REAL, -- Meter
   Kennzeichnung
      VARCHAR(15),
   Bemerkung
      VARCHAR(255),
   von_Sachverhalt
      INTEGER NOT NULL REFERENCES Sachverhalt
)

CREATE TABLE Bauwerksbeschilderung (
   Bauwerksbeschilderung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Schild_StVO_Zeichennummer
      VARCHAR(15),
   Schild_Bezeichnung
      VARCHAR(50),
   Schild_Mengenangabe
      VARCHAR(50),
   Schild_Angabe_Zusatzschild
      VARCHAR(50),
   Bauwerksbeschild_Bemerkung
      VARCHAR(255)
)

CREATE TABLE Bauwerksbelaege (
   Bauwerksbelaege_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Art_der_Belaege
      VARCHAR(15),
   Deckschichtkennzeichnung
      INTEGER REFERENCES Logical_Types.Boolean,
   Belaege_Einbauort
      VARCHAR(255),
   Schichtnummer
      INTEGER,
   Schichtdicke
      REAL, -- Millimeter
   CHECK ( Schichtdicke>=0 ),
   Einbaujahr
      INTEGER, -- Jahr
   Einbaumonat
      INTEGER, -- Monat
   CHECK ( ( Einbaumonat >= 1 ) AND ( Einbaumonat <= 12 ) ),
   Einbauflaeche
      REAL, -- Quadratmeter
   CHECK ( Einbauflaeche>=0 ),
   ausfuehrende_Firma
      VARCHAR(80),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Entwuerfe_und_Berechnungen (
   Entwuerfe_und_Berechnungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Art_Entw_und_Ber
      VARCHAR(15),
   Aufsteller_Entw_und_Ber
      VARCHAR(80),
   Bearbeiter_Entw_und_Ber
      VARCHAR(80),
   Aufstellungsjahr_Entw_und_Ber
      INTEGER, -- Jahr
   Bemerkungen_zu_Entw_und_Ber
      VARCHAR(255)
)

CREATE TABLE Bruecke (
   Bruecke_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bruecke_ID) REFERENCES Teilbauwerk,
   Gesamtlaenge_Bruecke
      REAL, -- Meter
   Breite_Bruecke
      REAL, -- Meter
   Gesamtbreite_Bruecke
      REAL, -- Meter
   Brueckenflaeche
      REAL, -- Quadratmeter
   CHECK ( Brueckenflaeche>=0 ),
   Zwischenraum_Ueberbauten
      REAL, -- Meter
   Konstruktionshoehe_min
      REAL, -- Meter
   Konstruktionshoehe_max
      REAL, -- Meter
   Anzahl_Felder_Bruecke
      INTEGER,
   Anzahl_Ueberbauten_Bruecke
      INTEGER,
   Laengsneigung_max
      REAL, -- Prozent
   Querneigung_max
      REAL, -- Prozent
   Kruemmung
      VARCHAR(15),
   Bauwerkswinkel
      REAL, -- Gon
   CHECK ( Bauwerkswinkel>=0 ),
   Winkelrichtung
      VARCHAR(15),
   Querschnitt_Ueberbau
      VARCHAR(15),
   Querschnitt_Haupttragwerk
      VARCHAR(15),
   Bauverfahren_Ueberbau
      VARCHAR(15),
   Konstr_Massn_nachtr_Verstaerk
      VARCHAR(15),
   maximale_Ueberschuettungshoehe
      REAL, -- Meter
   minimale_Ueberschuettungshoehe
      REAL, -- Meter
   lichte_Hoehe
      REAL, -- Meter
   lichte_Weite_b_Einfeldbruecke
      REAL, -- Meter
   Bemerkungen_zum_Baugrund
      VARCHAR(255),
   Bemerkungen_zur_Bruecke
      VARCHAR(255)
)

CREATE TABLE Bruecke__hat_Hauptbaust_Beton (
   Bruecke
      INTEGER NOT NULL REFERENCES Bruecke,
   Hauptbaustoff_Beton
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Beton
)

CREATE TABLE Bruecke__hat_Hauptbaust_St_H_K (
   Bruecke
      INTEGER NOT NULL REFERENCES Bruecke,
   Hauptbaustoff_Stahl_Holz_Kunst
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Stahl_Holz_Kunst
)

CREATE TABLE Bruecke__hat_Hauptbaust_Verb (
   Bruecke
      INTEGER NOT NULL REFERENCES Bruecke,
   Hauptbaustoff_Verbundwerkst
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Verbundwerkst
)

CREATE TABLE Bruecke__hat_Brueckenf_Stuetz (
   Bruecke
      INTEGER NOT NULL REFERENCES Bruecke,
   Brueckenfeld_Stuetzung
      INTEGER NOT NULL REFERENCES Brueckenfeld_Stuetzung
)

CREATE TABLE Verkehrszeichenbruecke (
   Verkehrszeichenbruecke_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Verkehrszeichenbruecke_ID) REFERENCES Teilbauwerk,
   Querschnitt_Stiel
      VARCHAR(15),
   Querschnitt_Riegel
      VARCHAR(15),
   Gesamtlaenge_des_Riegels
      REAL, -- Meter
   Besichtigungs_Wartungsoeffnung
      VARCHAR(15),
   Befest_Konstr_Schilder_Signalg
      VARCHAR(15),
   Bemerkung_Verkehrsz_Bruecke
      VARCHAR(255)
)

CREATE TABLE Verkzbr__hat_Hauptb_Beton (
   Verkehrszeichenbruecke
      INTEGER NOT NULL REFERENCES Verkehrszeichenbruecke,
   Hauptbaustoff_Beton
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Beton
)

CREATE TABLE Verkzbr__hat_Hauptb_St_H_K (
   Verkehrszeichenbruecke
      INTEGER NOT NULL REFERENCES Verkehrszeichenbruecke,
   Hauptbaustoff_Stahl_Holz_Kunst
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Stahl_Holz_Kunst
)

CREATE TABLE Verkzbr__hat_Hauptb_Verbundw (
   Verkehrszeichenbruecke
      INTEGER NOT NULL REFERENCES Verkehrszeichenbruecke,
   Hauptbaustoff_Verbundwerkst
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Verbundwerkst
)

CREATE TABLE Verkzeichenbr__hat_Bruefeld_St (
   Verkehrszeichenbruecke
      INTEGER NOT NULL REFERENCES Verkehrszeichenbruecke,
   Brueckenfeld_Stuetzung
      INTEGER NOT NULL REFERENCES Brueckenfeld_Stuetzung
)

CREATE TABLE Tunnel_Trogbauwerk (
   Tunnel_Trogbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Tunnel_Trogbauwerk_ID) REFERENCES Teilbauwerk,
   Gradiente
      VARCHAR(15),
   Rundungshalbmesser
      REAL, -- Meter
   minimale_Laengsneigung
      REAL, -- Prozent
   maximale_Laengsneigung
      REAL, -- Prozent
   minimaler_Radius_im_Grundriss
      REAL, -- Meter
   minimale_Ueberdeckungshoehe
      REAL, -- Meter
   maximale_Ueberdeckungshoehe
      REAL, -- Meter
   Hoehe_rel_NN_in_Tunnelmitte
      REAL, -- Meter
   Bauwerkslaenge
      REAL, -- Meter
   geschl_Laenge_der_Tunnelroehre
      REAL, -- Meter
   Tunnelflaeche
      REAL, -- Quadratmeter
   CHECK ( Tunnelflaeche>=0 ),
   Bauweise
      VARCHAR(15),
   Querschnitt
      VARCHAR(15),
   Ausbruchflaeche
      REAL, -- Quadratmeter
   CHECK ( Ausbruchflaeche>=0 ),
   Sicherung
      VARCHAR(255),
   Geologie
      VARCHAR(15),
   Grund_und_Gebirgswasserverh
      VARCHAR(255),
   Bauverfahren
      VARCHAR(15),
   Vortriebsverfahren
      VARCHAR(15),
   Bemerkungen_zum_Tunnel_Trogbau
      VARCHAR(255)
)

CREATE TABLE Tunnel_Trogbw__hat_Segmente (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Segment_Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Segment_Tunnel_Trogbauwerk
)

CREATE TABLE Tunnel_Trogbw__hat_Tunbeleucht (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnelbeleuchtung
      INTEGER NOT NULL REFERENCES Tunnelbeleuchtung
)

CREATE TABLE Tunnel_Trogbw__hat_Tunnellueft (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnellueftung
      INTEGER NOT NULL REFERENCES Tunnellueftung
)

CREATE TABLE Tunnel_Trogbw__hat_Zentr_Anl (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnel_Zentrale_Anlagen
      INTEGER NOT NULL REFERENCES Tunnel_Zentrale_Anlagen
)

CREATE TABLE Tunnel_Trogbw__hat_Tunsicherh (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnelsicherheit
      INTEGER NOT NULL REFERENCES Tunnelsicherheit
)

CREATE TABLE Tunnel_Trogbw__hat_Tunverkeinr (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnel_Verkehrseinrichtungen
      INTEGER NOT NULL REFERENCES Tunnel_Verkehrseinrichtungen
)

CREATE TABLE Tunn_Trogbw__hat_Hauptb_Beton (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Hauptbaustoff_Beton
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Beton
)

CREATE TABLE Tunn_Trogbw__hat_Hauptb_St_H_K (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Hauptbaustoff_Stahl_Holz_Kunst
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Stahl_Holz_Kunst
)

CREATE TABLE Tunn_Trogbw__hat_Hauptb_Verb (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Hauptbaustoff_Verbundwerkst
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Verbundwerkst
)

CREATE TABLE Laermschutzbauwerk (
   Laermschutzbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Laermschutzbauwerk_ID) REFERENCES Teilbauwerk,
   Gesamtlaenge
      REAL, -- Meter
   Flaeche_des_Laermschirmes
      REAL, -- Quadratmeter
   CHECK ( Flaeche_des_Laermschirmes >= 0 ),
   Bemerkungen_zum_Laermschutzbw
      VARCHAR(255)
)

CREATE TABLE Laermschbw__hat_Segmente (
   Laermschutzbauwerk
      INTEGER NOT NULL REFERENCES Laermschutzbauwerk,
   Segment_Laermschutzbauwerk
      INTEGER NOT NULL REFERENCES Segment_Laermschutzbauwerk
)

CREATE TABLE Stuetzbauwerk (
   Stuetzbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Stuetzbauwerk_ID) REFERENCES Teilbauwerk,
   Gesamtlaenge_Stuetzbauwerk
      REAL, -- Meter
   Flaeche_Stuetzbauwerk
      REAL, -- Quadratmeter
   CHECK ( Flaeche_Stuetzbauwerk>=0 ),
   Bemerkungen_zum_Stuetzbauwerk
      VARCHAR(255)
)

CREATE TABLE Stuetzbauwerk__hat_Segmente (
   Stuetzbauwerk
      INTEGER NOT NULL REFERENCES Stuetzbauwerk,
   Segment_Stuetzbauwerk
      INTEGER NOT NULL REFERENCES Segment_Stuetzbauwerk
)

CREATE TABLE sonstiges_Bauwerk (
   sonstiges_Bauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (sonstiges_Bauwerk_ID) REFERENCES Teilbauwerk,
   Stuetzweite_sonstiges_Bauwerk
      REAL, -- Meter
   Beschreibung_sonstiges_Bauwerk
      VARCHAR(255)
)

CREATE TABLE sonst_Bw__hat_Hauptb_Beton (
   sonstiges_Bauwerk
      INTEGER NOT NULL REFERENCES sonstiges_Bauwerk,
   Hauptbaustoff_Beton
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Beton
)

CREATE TABLE sonst_Bw__hat_Hauptb_St_H_K (
   sonstiges_Bauwerk
      INTEGER NOT NULL REFERENCES sonstiges_Bauwerk,
   Hauptbaustoff_Stahl_Holz_Kunst
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Stahl_Holz_Kunst
)

CREATE TABLE sonst_Bw__hat_Hauptb_Verbundw (
   sonstiges_Bauwerk
      INTEGER NOT NULL REFERENCES sonstiges_Bauwerk,
   Hauptbaustoff_Verbundwerkst
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Verbundwerkst
)

CREATE TABLE Brueckenfeld_Stuetzung (
   Brueckenfeld_Stuetzung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Art_der_Stuetzung
      VARCHAR(15),
   Feldnummer
      INTEGER,
   Stuetzweite
      REAL, -- Meter
   Stuetzungshoehe
      REAL, -- Meter
   Anzahl_d_Stuetzen_einer_Reihe
      INTEGER,
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Segment_Tunnel_Trogbauwerk (
   Segment_Tunnel_Trogbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Segmentlaenge
      REAL, -- Meter
   Oberflaeche_Tunneldecke
      VARCHAR(15),
   Oberflaeche_Tunnelwaende
      VARCHAR(15),
   Hoehe_Segmentanfang_rechts
      REAL, -- Meter
   Hoehe_Segmentanfang_links
      REAL, -- Meter
   Hoehe_Segmentende_rechts
      REAL, -- Meter
   Hoehe_Segmentende_links
      REAL, -- Meter
   Bemerkungen_Segm_Tunnel_Trogbw
      VARCHAR(255)
)

CREATE TABLE Segment_Laermschutzbauwerk (
   Segment_Laermschutzbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Segmentlaenge_Laermschutz
      REAL, -- Meter
   Hoehe_Segmentanfang
      REAL, -- Meter
   Hoehe_Segmentende
      REAL, -- Meter
   Pfostenabstand
      REAL, -- Meter
   Standort_des_Pfostens
      VARCHAR(15),
   Untergrund
      VARCHAR(15),
   Fangvorrichtung
      VARCHAR(15),
   Vogelschutz
      VARCHAR(15),
   akustische_Eig_Vorsatzschale
      VARCHAR(15),
   Pflanzungen_Verkehrsseite
      VARCHAR(15),
   Pflanzungen_Anliegerseite
      VARCHAR(15),
   Besichtigungsweg_Anliegerseite
      VARCHAR(15),
   Bemerkungen_Laermschutz
      VARCHAR(255)
)

CREATE TABLE Segment_Stuetzbauwerk (
   Segment_Stuetzbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Segmentlaenge_Stuetzbauwerk
      REAL, -- Meter
   Hoehe_Segmentanfang_Stuetzbw
      REAL, -- Meter
   Hoehe_Segmentende_Stuetzbw
      REAL, -- Meter
   Besichtigungsweg_Anliegerseite
      VARCHAR(15),
   Bemerkungen_zum_Stuetzbauwerk
      VARCHAR(255)
)

CREATE TABLE Pruefanweisungen (
   Pruefanweisungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   abweichende_Pruefpflicht
      VARCHAR(15),
   Pruefanweisungen
      VARCHAR(255),
   Tauchereinsatz
      VARCHAR(15),
   Pruefung_elektr_Einrichtungen
      VARCHAR(15),
   Pruefung_maschn_Einrichtungen
      VARCHAR(15),
   Bemerkungen_zur_Pruefanweisung
      VARCHAR(255)
)

CREATE TABLE durchgef_Pruefungen_Messungen (
   durchgef_Pruefungen_Messungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Art_der_Pruefung
      VARCHAR(80),
   Pruefungs_Messungsdatum
      CHAR(10), -- Datum
   CHECK ( Pruefungs_Messungsdatum LIKE '__.__.____' ),
   Pruefungs_Messungszyklus
      INTEGER,
   Zustandsnote
      FLOAT (3),
   Bemerkungen_zur_durchgef_Prfg
      VARCHAR(255)
)

CREATE TABLE gegenw_dokum_Schadensstand (
   gegenw_dokum_Schadensstand_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Menge_allgemein
      VARCHAR(15),
   Menge_mit_Dimension_Schluessel
      VARCHAR(15),
   Menge_mit_Dimension
      VARCHAR(20),
   Ortsbest_Feld_Pfeiler_Block
      VARCHAR(15),
   Ortsbest_Feld_Pfeiler_Block_W
      VARCHAR(20),
   Ortsbestimmung_Ueberbau
      VARCHAR(15),
   Ortsbestimmung_Ueberbau_Werte
      VARCHAR(20),
   Ortsbest_laengs_Schluessel
      VARCHAR(15),
   Ortsbestimmung_laengs_Werte
      VARCHAR(20),
   Ortsbestimmung_quer
      VARCHAR(15),
   Ortsbestimmung_quer_Werte
      VARCHAR(20),
   Ortsbestimmung_hoch_Schluessel
      VARCHAR(15),
   Ortsbestimmung_hoch_Werte
      VARCHAR(20),
   Schadensbewertung
      VARCHAR(15),
   Bewertung_Standsicherheit
      INTEGER, -- Schadensbewertung
   CHECK ( { 0<=Bewertung_Standsicherheit<=4} ),
   Bewertung_Verkehrssicherheit
      INTEGER, -- Schadensbewertung
   CHECK ( { 0<=Bewertung_Verkehrssicherheit<=4} ),
   Bewertung_Dauerhaftigkeit
      INTEGER, -- Schadensbewertung
   CHECK ( { 0<=Bewertung_Dauerhaftigkeit<=4} ),
   Schadensveraenderungen
      VARCHAR(15),
   Bemerkung_Schluessel_1
      VARCHAR(15),
   Bemerkung_Schluessel_2
      VARCHAR(15),
   Bemerkung_Schluessel_3
      VARCHAR(15),
   Bemerkung_Schluessel_4
      VARCHAR(15),
   Bemerkung_Schluessel_5
      VARCHAR(15),
   Bemerkung_Schluessel_6
      VARCHAR(15),
   Bemerkung_Text_1
      VARCHAR(20),
   Bemerkung_Text_2
      VARCHAR(20),
   Bemerkung_Text_3
      VARCHAR(20),
   Bemerkung_Text_4
      VARCHAR(20),
   Bemerkung_Text_5
      VARCHAR(20),
   Bemerkung_Text_6
      VARCHAR(20),
   Hauptbauteil
      VARCHAR(15),
   Konstruktionsteil
      VARCHAR(15),
   Bauteilergaenzung
      VARCHAR(15),
   Schaden
      VARCHAR(15),
   Schaden_Werte
      VARCHAR(20),
   Schadenstext
      VARCHAR(255),
   Pfad_Schadensbild
      VARCHAR(128),
   Pruefjahr
      INTEGER, -- Jahr
   Pruefart
      VARCHAR(2),
   Vormerkung_einfache_Pruefung
      INTEGER REFERENCES Logical_Types.Boolean,
   von_gegenw_dok_Pruefungsstand
      INTEGER REFERENCES gegenw_dokum_Pruefungsstand
)

CREATE TABLE gegenw_dokum_Pruefungsstand (
   gegenw_dokum_Pruefungsstand_ID
      INTEGER NOT NULL PRIMARY KEY,
   Allgemeine_Empfehlungen
      VARCHAR(255),
   Prueftext
      VARCHAR(255),
   Zustandsnote
      REAL,
   Empfehlung_Schluessel_1
      VARCHAR(15),
   Empfehlung_Menge_1
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_1 >= 0 ),
   Empfehlung_Schluessel_2
      VARCHAR(15),
   Empfehlung_Menge_2
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_2 >= 0 ),
   Empfehlung_Schluessel_3
      VARCHAR(15),
   Empfehlung_Menge_3
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_3 >= 0 ),
   Empfehlung_Schluessel_4
      VARCHAR(15),
   Empfehlung_Menge_4
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_4 >= 0 ),
   Empfehlung_Schluessel_5
      VARCHAR(15),
   Empfehlung_Menge_5
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_5 >= 0 ),
   Empfehlung_Schluessel_6
      VARCHAR(15),
   Empfehlung_Menge_6
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_6 >= 0 ),
   Empfehlung_Schluessel_7
      VARCHAR(15),
   Empfehlung_Menge_7
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_7 >= 0 ),
   Empfehlung_Schluessel_8
      VARCHAR(15),
   Empfehlung_Menge_8
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_8 >= 0 ),
   Empfehlung_Schluessel_9
      VARCHAR(15),
   Empfehlung_Menge_9
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_9 >= 0 ),
   Empfehlung_Schluessel_10
      VARCHAR(15),
   Empfehlung_Menge_10
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_10 >= 0 ),
   CHECK ( Empfehlung_Menge_10 <= 100000 ),
   CHECK ( Empfehlung_Menge_9 <= 100000 ),
   CHECK ( Empfehlung_Menge_8 <= 100000 ),
   CHECK ( Empfehlung_Menge_7 <= 100000 ),
   CHECK ( Empfehlung_Menge_6 <= 100000 ),
   CHECK ( Empfehlung_Menge_5 <= 100000 ),
   CHECK ( Empfehlung_Menge_4 <= 100000 ),
   CHECK ( Empfehlung_Menge_3 <= 100000 ),
   CHECK ( Empfehlung_Menge_2 <= 100000 ),
   CHECK ( Empfehlung_Menge_1 <= 100000 ),
   CHECK ( (Zustandsnote >= 1) AND (Zustandsnote <= 4) )
)

CREATE TABLE Schadensdaten_abgeschl_Prfg (
   Schadensdaten_abgeschl_Prfg_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Menge_allgemein
      VARCHAR(15),
   Menge_mit_Dimension_Schluessel
      VARCHAR(15),
   Menge_mit_Dimension
      VARCHAR(20),
   Ortsbest_Feld_Pfeiler_Block
      VARCHAR(15),
   Ortsbest_Feld_Pfeiler_Block_W
      VARCHAR(20),
   Ortsbestimmung_Ueberbau
      VARCHAR(15),
   Ortsbestimmung_Ueberbau_Werte
      VARCHAR(20),
   Ortsbest_laengs_Schluessel
      VARCHAR(15),
   Ortsbestimmung_laengs_Werte
      VARCHAR(20),
   Ortsbestimmung_quer
      VARCHAR(15),
   Ortsbestimmung_quer_Werte
      VARCHAR(20),
   Ortsbestimmung_hoch_Schluessel
      VARCHAR(15),
   Ortsbestimmung_hoch_Werte
      VARCHAR(20),
   Schadensbewertung
      VARCHAR(15),
   Bewertung_Standsicherheit
      INTEGER, -- Schadensbewertung
   CHECK ( { 0<=Bewertung_Standsicherheit<=4} ),
   Bewertung_Verkehrssicherheit
      INTEGER, -- Schadensbewertung
   CHECK ( { 0<=Bewertung_Verkehrssicherheit<=4} ),
   Bewertung_Dauerhaftigkeit
      INTEGER, -- Schadensbewertung
   CHECK ( { 0<=Bewertung_Dauerhaftigkeit<=4} ),
   Schadensveraenderungen
      VARCHAR(15),
   Bemerkung_Schluessel_1
      VARCHAR(15),
   Bemerkung_Schluessel_2
      VARCHAR(15),
   Bemerkung_Schluessel_3
      VARCHAR(15),
   Bemerkung_Schluessel_4
      VARCHAR(15),
   Bemerkung_Schluessel_5
      VARCHAR(15),
   Bemerkung_Schluessel_6
      VARCHAR(15),
   Bemerkung_Text_1
      VARCHAR(20),
   Bemerkung_Text_2
      VARCHAR(20),
   Bemerkung_Text_3
      VARCHAR(20),
   Bemerkung_Text_4
      VARCHAR(20),
   Bemerkung_Text_5
      VARCHAR(20),
   Bemerkung_Text_6
      VARCHAR(20),
   Hauptbauteil
      VARCHAR(15),
   Konstruktionsteil
      VARCHAR(15),
   Bauteilergaenzung
      VARCHAR(15),
   Schaden
      VARCHAR(15),
   Schaden_Werte
      VARCHAR(20),
   Schadenstext
      VARCHAR(255),
   Pfad_Schadensbild
      VARCHAR(128),
   Pruefjahr
      INTEGER, -- Jahr
   Pruefart
      VARCHAR(2),
   Vormerkung_einfache_Pruefung
      INTEGER REFERENCES Logical_Types.Boolean,
   von_Pruefungsdaten_abg_Prfg
      INTEGER REFERENCES Pruefungsdaten_abgeschl_Prfg
)

CREATE TABLE Pruefungsdaten_abgeschl_Prfg (
   Pruefungsdaten_abgeschl_Prfg_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Pruefjahr
      INTEGER NOT NULL, -- Jahr
   Pruefart
      VARCHAR(2) NOT NULL,
   Pruefrichtung
      VARCHAR(80),
   Pruefer
      VARCHAR(30),
   Dienstelle_Pruefer
      VARCHAR(30),
   Pruefungsbeginn
      CHAR(10), -- Datum
   CHECK ( Pruefungsbeginn LIKE '__.__.____' ),
   Abschluss_Schadenerfassung
      CHAR(10), -- Datum
   CHECK ( Abschluss_Schadenerfassung LIKE '__.__.____' ),
   Pruefungsabschluss
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Pruefungsabschluss LIKE '__.__.____' ),
   Allgemeine_Empfehlungen
      VARCHAR(255),
   Prueftext
      VARCHAR(255),
   Zustandsnote
      REAL,
   Empfehlung_Schluessel_1
      VARCHAR(15),
   Empfehlung_Menge_1
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_1 >= 0 ),
   Empfehlung_Schluessel_2
      VARCHAR(15),
   Empfehlung_Menge_2
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_2 >= 0 ),
   Empfehlung_Schluessel_3
      VARCHAR(15),
   Empfehlung_Menge_3
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_3 >= 0 ),
   Empfehlung_Schluessel_4
      VARCHAR(15),
   Empfehlung_Menge_4
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_4 >= 0 ),
   Empfehlung_Schluessel_5
      VARCHAR(15),
   Empfehlung_Menge_5
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_5 >= 0 ),
   Empfehlung_Schluessel_6
      VARCHAR(15),
   Empfehlung_Menge_6
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_6 >= 0 ),
   Empfehlung_Schluessel_7
      VARCHAR(15),
   Empfehlung_Menge_7
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_7 >= 0 ),
   Empfehlung_Schluessel_8
      VARCHAR(15),
   Empfehlung_Menge_8
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_8 >= 0 ),
   Empfehlung_Schluessel_9
      VARCHAR(15),
   Empfehlung_Menge_9
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_9 >= 0 ),
   Empfehlung_Schluessel_10
      VARCHAR(15),
   Empfehlung_Menge_10
      REAL, -- Groesse
   CHECK ( Empfehlung_Menge_10 >= 0 ),
   CHECK ( Empfehlung_Menge_10 <= 100000 ),
   CHECK ( Empfehlung_Menge_9 <= 100000 ),
   CHECK ( Empfehlung_Menge_8 <= 100000 ),
   CHECK ( Empfehlung_Menge_7 <= 100000 ),
   CHECK ( Empfehlung_Menge_6 <= 100000 ),
   CHECK ( Empfehlung_Menge_5 <= 100000 ),
   CHECK ( Empfehlung_Menge_4 <= 100000 ),
   CHECK ( Empfehlung_Menge_3 <= 100000 ),
   CHECK ( Empfehlung_Menge_2 <= 100000 ),
   CHECK ( Empfehlung_Menge_1 <= 100000 ),
   CHECK ( (Zustandsnote >= 1) AND (Zustandsnote <= 4) )
)

CREATE TABLE Prueffahrzeuge_Pruefgeraete (
   Prueffahrzeuge_Pruefgeraete_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Geraeteart
      VARCHAR(15),
   voraussichtl_Einsatzdauer
      INTEGER, -- Tage
   CHECK ( voraussichtl_Einsatzdauer >= 0 ),
   Bemerkungen_zu_Prueffahrzeugen
      VARCHAR(255)
)

CREATE TABLE Anlagen_Bauwerksbuch (
   Anlagen_Bauwerksbuch_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Beschreibung_sonst_Anlagen
      VARCHAR(255)
)

CREATE TABLE Verwaltungsmassn_Sondervereinb (
   Verwaltungsmassn_Sondervereinb_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Aktenzeichen_des_Verw_Akt
      VARCHAR(30),
   Veranlasser
      VARCHAR(80),
   Wirksamkeitsdatum
      CHAR(10), -- Datum
   CHECK ( Wirksamkeitsdatum LIKE '__.__.____' ),
   Beschreibung_der_Massnahme
      VARCHAR(255)
)

CREATE TABLE Verwmassn_Sonderv__von_Teilbw (
   Verwaltungsmassn_Sondervereinb
      INTEGER NOT NULL REFERENCES Verwaltungsmassn_Sondervereinb,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Bau_und_Erhaltungsmassnahme (
   Bau_und_Erhaltungsmassnahme_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Baumassnahme
      VARCHAR(80),
   Bezeichnung_der_Baumassnahme
      VARCHAR(80),
   Baujahr
      INTEGER, -- Jahr
   Auftragssumme
      REAL, -- DM
   CHECK ( Auftragssumme >= 0 ),
   Abrechnungssumme
      REAL, -- DM
   CHECK ( Abrechnungssumme >= 0 ),
   Waehrung
      REAL, -- Waehrung
   CHECK ( Waehrung >= 0 ),
   Auftraggeber_Bau_Erh_Massn
      VARCHAR(80),
   Auftragnehmer_Bau_Erh_Massn
      VARCHAR(80),
   Bauueberwachung
      VARCHAR(80),
   Baubeginn_Bau_Erh_Massn
      CHAR(10), -- Datum
   CHECK ( Baubeginn_Bau_Erh_Massn LIKE '__.__.____' ),
   Bauende_Bau_Erh_Massn
      CHAR(10), -- Datum
   CHECK ( Bauende_Bau_Erh_Massn LIKE '__.__.____' ),
   Ablauf_Gewaehrleistung
      CHAR(10), -- Datum
   CHECK ( Ablauf_Gewaehrleistung LIKE '__.__.____' ),
   Bemerkungen_Bau_Erh_Massn
      VARCHAR(255)
)

CREATE TABLE Bau_und_Erhmassn__von_Teilbw (
   Bau_und_Erhaltungsmassnahme
      INTEGER NOT NULL REFERENCES Bau_und_Erhaltungsmassnahme,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Bau_u_Erhaltmassn__hat_Kosten (
   Bau_und_Erhaltungsmassnahme
      INTEGER NOT NULL REFERENCES Bau_und_Erhaltungsmassnahme,
   Kosten_fuer_Bau_Erh_und_Betr
      INTEGER NOT NULL REFERENCES Kosten_fuer_Bau_Erh_und_Betr
)

CREATE TABLE Kosten_fuer_Bau_Erh_und_Betr (
   Kosten_fuer_Bau_Erh_und_Betr_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Kostenart_Bau_Erh_Kosten
      VARCHAR(10),
   Menge_Bau_Erh_Kosten
      FLOAT (12),
   Haushaltsjahr_Bau_Erh_Kosten
      INTEGER, -- Jahr
   Kostentraeger_Bau_Erh_Kosten
      VARCHAR(120),
   Titel_Bau_Erh_Kosten
      VARCHAR(20),
   Ausgabe_Bau_Erh_Kosten
      REAL, -- DM
   CHECK ( Ausgabe_Bau_Erh_Kosten>=0 ),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Ausstattung (
   Ausstattung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Art
      VARCHAR(10),
   Einbauort
      VARCHAR(255),
   TUEV_Datum
      CHAR(10), -- Datum
   CHECK ( TUEV_Datum LIKE '__.__.____' ),
   Bemerkungen_zu_Ausstattungen
      VARCHAR(255)
)

CREATE TABLE Schutzeinrichtungen (
   Schutzeinrichtungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Art_Schutzeinrichtung
      VARCHAR(15),
   Einbauort_Schutzeinrichtung
      VARCHAR(255),
   Einbaujahr_Schutzeinrichtung
      INTEGER, -- Jahr
   Laenge_Schutzeinrichtung
      REAL, -- Meter
   Hoehe_Schutzeinrichtung
      REAL, -- Meter
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Vorspannungen (
   Vorspannungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Richtung
      VARCHAR(15),
   intern_extern
      VARCHAR(15),
   Vorspannungsgrad
      VARCHAR(15),
   Spannverfahren
      VARCHAR(15),
   Spannkraft
      REAL, -- Kilonewton
   CHECK ( Spannkraft >= 0 ),
   Spannstahl_Streckgrenze
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Spannstahl_Streckgrenze >= 0 ),
   Spannstahl_Bruchgrenze
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Spannstahl_Bruchgrenze >= 0 ),
   Hersteller
      VARCHAR(15),
   Art_der_Verpressung
      VARCHAR(15),
   Typenbezeichnung
      VARCHAR(80),
   Einbaujahr_Vorspannung
      INTEGER, -- Jahr
   Einbauort_Vorspannung
      VARCHAR(255),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Gruendungen (
   Gruendungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Art_der_Gruendungen
      VARCHAR(15),
   Typenbezeichnung_Gruendung
      VARCHAR(80),
   Einbauort_Gruendung
      VARCHAR(255),
   Einbaujahr_Gruendung
      INTEGER, -- Jahr
   Bemerkungen_zur_Gruendung
      VARCHAR(255)
)

CREATE TABLE Erd_und_Felsanker (
   Erd_und_Felsanker_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Verfahren_Erd_und_Felsanker
      VARCHAR(15),
   Hersteller_Erd_und_Felsanker
      VARCHAR(15),
   Zulassungsnummer
      VARCHAR(50),
   Anzahl_Erd_und_Felsanker
      INTEGER,
   Art_Erd_und_Felsanker
      VARCHAR(255),
   Typenbez_Erd_und_Felsanker
      VARCHAR(80),
   Einbauort_Erd_und_Felsanker
      VARCHAR(255),
   Einbaujahr_Erd_und_Felsanker
      INTEGER, -- Jahr
   Bemerkungen_Erd_und_Felsanker
      VARCHAR(255)
)

CREATE TABLE Lager (
   Lager_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Anzahl_der_Lager
      INTEGER,
   Art_der_Lager
      VARCHAR(15),
   Typenbezeichnung
      VARCHAR(80),
   Einbauort_der_Lager
      VARCHAR(255),
   Einbaujahr_der_Lager
      INTEGER, -- Jahr
   Hersteller
      VARCHAR(15),
   Bemerkungen
      VARCHAR(255),
   von_Brueckenfeld_Stuetzung
      INTEGER NOT NULL REFERENCES Brueckenfeld_Stuetzung
)

CREATE TABLE Fahrbahnuebergangskonstruktion (
   Fahrbahnuebergangskonstruktion_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Art_Fahrbahnuebergang
      VARCHAR(15),
   Anzahl_Fahrbahnuebergaenge
      INTEGER,
   Anzahl_der_Lamellen
      INTEGER,
   Gesamtdehnweg
      REAL, -- Millimeter
   CHECK ( Gesamtdehnweg >= 0 ),
   Hersteller_Fahrbahnuebergaenge
      VARCHAR(15),
   Typenbez_Fahrbahnuebergaenge
      VARCHAR(80),
   regelgepr_Fahrbahnuebergaenge
      VARCHAR(15),
   Einbauort_Fahrbahnuebergaenge
      VARCHAR(255),
   Einbaujahr_Fahrbahnuebergaenge
      INTEGER, -- Jahr
   Konstruktionslaenge_Uebergang
      REAL, -- Meter
   Wartungsg_Fahrbahnuebergaenge
      VARCHAR(15),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Kappe (
   Kappe_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Einbauort_Kappe
      VARCHAR(255),
   Konstruktion_Kappe
      VARCHAR(15),
   Verankerung_Kappe
      VARCHAR(15),
   Ankerabstand
      REAL, -- Meter
   groesste_Blocklaenge
      REAL, -- Meter
   Breite_Kappe
      REAL, -- Meter
   Einbaujahr_Kappe
      INTEGER, -- Jahr
   Bemerkungen_zur_Kappe
      VARCHAR(255)
)

CREATE TABLE Brueckenseile_und_kabel (
   Brueckenseile_und_kabel_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Seilart
      VARCHAR(15),
   Hersteller
      VARCHAR(15),
   Tragfunktion
      VARCHAR(15),
   Seillaenge
      REAL, -- Meter
   Seildurchmesser
      REAL, -- Millimeter
   CHECK ( Seildurchmesser >= 0 ),
   Seilquerschnitt_metallisch
      REAL, -- Quadratmillimeter
   CHECK ( Seilquerschnitt_metallisch >= 0 ),
   Drahtfestigkeit
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Drahtfestigkeit >= 0 ),
   Seilkraft
      REAL, -- Kilonewton
   CHECK ( Seilkraft >= 0 ),
   Verformungsmodul
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Verformungsmodul >= 0 ),
   Schlaglaenge
      REAL, -- Millimeter
   CHECK ( Schlaglaenge >= 0 ),
   Gesamtgewicht
      REAL, -- Tonnen
   CHECK ( Gesamtgewicht >= 0 ),
   Seilverfuellmittel
      VARCHAR(15),
   Seilaufbau
      VARCHAR(15),
   Oberflaechenbeh_des_Drahtes
      VARCHAR(15),
   Oberflaechenbeh_Seilaufbau
      VARCHAR(15),
   Vergusshuelse_Seilkopf
      VARCHAR(15),
   Werkstoff_Vergusshuelse
      VARCHAR(15),
   Seilverguss
      VARCHAR(15),
   Armaturen
      VARCHAR(15),
   schwingungsdaempf_Massnahmen
      VARCHAR(15),
   Bemerkungen_zu_Brueckenseile
      VARCHAR(255)
)

CREATE TABLE Abdichtungen (
   Abdichtungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Einbauort_Abdichtungen
      VARCHAR(255),
   Unterlage
      VARCHAR(15),
   Vorbereitung_der_Unterlage
      VARCHAR(15),
   Behandlung_der_Unterlage
      VARCHAR(15),
   Abdichtung
      VARCHAR(15),
   Schutzschicht
      VARCHAR(15),
   Dicke_Schutzschicht
      REAL, -- Zentimeter
   CHECK ( Dicke_Schutzschicht >= 0 ),
   Einbaujahr_Abdichtungen
      INTEGER, -- Jahr
   Flaeche_Abdichtungen
      REAL, -- Quadratmeter
   CHECK ( Flaeche_Abdichtungen >= 0 ),
   Hersteller_Abdichtungen
      VARCHAR(80),
   Ausfuehr_Firma_Abdichtungen
      VARCHAR(80),
   Bemerkungen_zu_Abdichtungen
      VARCHAR(255)
)

CREATE TABLE statisches_System_Tragfaehigkt (
   statisches_System_Tragfaehigkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   stat_System_in_Bauwerksachse
      VARCHAR(15),
   stat_System_quer_zu_Bauw_achse
      VARCHAR(15),
   Sonderabtragungsrichtung
      VARCHAR(15),
   Ersatzstuetzweite
      FLOAT (7),
   Tragfaehigkeit
      VARCHAR(15),
   Bemessungsfahrzeug_Hauptspur
      REAL, -- Tonnen
   CHECK ( Bemessungsfahrzeug_Hauptspur >= 0 ),
   Bemessungsfahrzeug_Nebenspur
      REAL, -- Tonnen
   CHECK ( Bemessungsfahrzeug_Nebenspur >= 0 ),
   statischer_Auslastungsgrad
      REAL, -- Prozent
   Bemessungslast
      REAL, -- Kilonewton
   CHECK ( Bemessungslast >= 0 ),
   Einstufungsjahr
      INTEGER, -- Jahr
   Massgeb_Tragfaehigkeitseinstuf
      INTEGER REFERENCES Logical_Types.Boolean,
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Hauptbaustoff_Beton (
   Hauptbaustoff_Beton_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Hauptbaustoff_des_Ueberbaus
      INTEGER REFERENCES Logical_Types.Boolean,
   Hauptbaustoff
      VARCHAR(15),
   Zement
      VARCHAR(15),
   Zuschlagstoff
      VARCHAR(255),
   Betonzusatz
      VARCHAR(255),
   Betondruckfestigkeit
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Betondruckfestigkeit >= 0 ),
   Oberflaeche_Hauptbaust_Beton
      VARCHAR(15),
   Betonstahlguete
      VARCHAR(15),
   Fertigteile
      VARCHAR(15),
   Lieferfirma_Hauptbaust_Beton
      VARCHAR(80),
   Bemerkungen_Hauptbaust_Beton
      VARCHAR(255),
   von_Ausstattung
      INTEGER REFERENCES Ausstattung,
   von_Brueckenseile_und_kabel
      INTEGER REFERENCES Brueckenseile_und_kabel,
   von_Erd_und_Felsanker
      INTEGER REFERENCES Erd_und_Felsanker,
   von_Fahrbahnuebergangskonstr
      INTEGER REFERENCES Fahrbahnuebergangskonstruktion,
   von_Gruendungen
      INTEGER REFERENCES Gruendungen,
   von_Kappen
      INTEGER REFERENCES Kappe,
   von_Lager
      INTEGER REFERENCES Lager,
   von_Schutzeinrichtungen
      INTEGER REFERENCES Schutzeinrichtungen,
   von_Segment_Laermschutzbauwerk
      INTEGER REFERENCES Segment_Laermschutzbauwerk,
   von_Segment_Stuetzbauwerk
      INTEGER REFERENCES Segment_Stuetzbauwerk,
   von_Vorspannungen
      INTEGER REFERENCES Vorspannungen
)

CREATE TABLE Hauptbaustoff_Stahl_Holz_Kunst (
   Hauptbaustoff_Stahl_Holz_Kunst_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Hauptbaustoff_des_Ueberbaus
      INTEGER REFERENCES Logical_Types.Boolean,
   Hauptbaustoff_Stahl
      VARCHAR(80),
   Konstruktionsstahlguete
      VARCHAR(80),
   Verbindungsmittel_zum_Stahl
      VARCHAR(80),
   Lieferfirma_Stahl
      VARCHAR(80),
   Bemerkungen_zum_Stahl
      VARCHAR(255),
   von_Ausstattung
      INTEGER REFERENCES Ausstattung,
   von_Brueckenseile_und_kabel
      INTEGER REFERENCES Brueckenseile_und_kabel,
   von_Erd_und_Felsanker
      INTEGER REFERENCES Erd_und_Felsanker,
   von_Fahrbahnuebergangskonstr
      INTEGER REFERENCES Fahrbahnuebergangskonstruktion,
   von_Gruendungen
      INTEGER REFERENCES Gruendungen,
   von_Kappen
      INTEGER REFERENCES Kappe,
   von_Lager
      INTEGER REFERENCES Lager,
   von_Schutzeinrichtungen
      INTEGER REFERENCES Schutzeinrichtungen,
   von_Segment_Laermschutzbauwerk
      INTEGER REFERENCES Segment_Laermschutzbauwerk,
   von_Segment_Stuetzbauwerk
      INTEGER REFERENCES Segment_Stuetzbauwerk,
   von_Vorspannungen
      INTEGER REFERENCES Vorspannungen
)

CREATE TABLE Hauptbst_SHK__hat_Korrosschutz (
   Hauptbaustoff_Stahl_Holz_Kunst
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Stahl_Holz_Kunst,
   Korrosionsschutzbeschichtungen
      INTEGER NOT NULL REFERENCES Korrosionsschutzbeschichtungen
)

CREATE TABLE Hauptbaustoff_Verbundwerkst (
   Hauptbaustoff_Verbundwerkst_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Hauptbaustoff_des_Ueberbaus
      INTEGER REFERENCES Logical_Types.Boolean,
   Hauptbaustoff_Verbundwerkst
      VARCHAR(15),
   Verbindungsmittel
      VARCHAR(15),
   Lieferfirma_Verbundwerkstoff
      VARCHAR(80),
   Bemerkungen_zum_Verbundwerkst
      VARCHAR(255),
   von_Ausstattung
      INTEGER REFERENCES Ausstattung,
   von_Brueckenseile_und_kabel
      INTEGER REFERENCES Brueckenseile_und_kabel,
   von_Erd_und_Felsanker
      INTEGER REFERENCES Erd_und_Felsanker,
   von_Fahrbahnuebergangskonstr
      INTEGER REFERENCES Fahrbahnuebergangskonstruktion,
   von_Gruendungen
      INTEGER REFERENCES Gruendungen,
   von_Kappen
      INTEGER REFERENCES Kappe,
   von_Lager
      INTEGER REFERENCES Lager,
   von_Schutzeinrichtungen
      INTEGER REFERENCES Schutzeinrichtungen,
   von_Segment_Laermschutzbauwerk
      INTEGER REFERENCES Segment_Laermschutzbauwerk,
   von_Segment_Stuetzbauwerk
      INTEGER REFERENCES Segment_Stuetzbauwerk,
   von_Vorspannungen
      INTEGER REFERENCES Vorspannungen
)

CREATE TABLE Gestaltungen (
   Gestaltungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Art_Gestaltung
      VARCHAR(255),
   Einbauort_Gestaltung
      VARCHAR(255),
   Bemerkungen_zur_Gestaltung
      VARCHAR(255)
)

CREATE TABLE Leitungen_an_Bauwerken (
   Leitungen_an_Bauwerken_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Leitungsarten_an_Bauwerken
      VARCHAR(15),
   Einbauort_Leitungen
      VARCHAR(255),
   Durchmesser
      REAL, -- Millimeter
   CHECK ( Durchmesser >= 0 ),
   Betreiber_der_Leitung
      VARCHAR(255),
   Buendelung
      VARCHAR(15),
   Anzahl_der_Leitungen_an_Bw
      INTEGER,
   Nutzungsvereinbarung
      VARCHAR(15),
   Bemerkungen_zu_Leitungen_an_Bw
      VARCHAR(255)
)

CREATE TABLE Verfuellungen (
   Verfuellungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Einbauort_Verfuellung
      VARCHAR(255),
   Schaden_Schadenursache
      VARCHAR(255),
   Fuellgut_Fuellmaterial
      VARCHAR(15),
   Hersteller_Produktbezeichnung
      VARCHAR(15),
   Einbaujahr_Verfuellung
      INTEGER, -- Jahr
   Ausfuehrende_Firma_Verfuellung
      VARCHAR(80),
   Bemerkungen_zur_Verfuellung
      VARCHAR(255)
)

CREATE TABLE Betonersatz_nach_ZTV_SIB (
   Betonersatz_nach_ZTV_SIB_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Art_des_Betonersatzsystems
      VARCHAR(15),
   Einbauort_Betonersatzsystem
      VARCHAR(255),
   Lieferfirma_Produktbezeichnung
      VARCHAR(15),
   Ausfuehrende_Firma_Betonersatz
      VARCHAR(80),
   Bezeichnung_zum_Betonersatz
      VARCHAR(80),
   Einbaujahr_Betonersatzsystem
      INTEGER, -- Jahr
   Flaeche_Betonersatzsystem
      REAL, -- Quadratmeter
   CHECK ( Flaeche_Betonersatzsystem >= 0 ),
   Bemerkungen_zum_Betonersatz
      VARCHAR(255)
)

CREATE TABLE Oberflschutz_nach_ZTV_SIB (
   Oberflschutz_nach_ZTV_SIB_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Art_des_Systems
      VARCHAR(15),
   Art_der_schuetzenden_Oberfl
      VARCHAR(15),
   Hersteller_Produktbezeichnung
      VARCHAR(15),
   Bezeichnung
      VARCHAR(80),
   Einbauort
      VARCHAR(255),
   Verbrauch
      REAL, -- Kilogramm_pro_Quadratmeter
   CHECK ( Verbrauch >= 0 ),
   Ausfuehrende_Firma
      VARCHAR(80),
   Einbaujahr
      INTEGER, -- Jahr
   Flaeche
      REAL, -- Quadratmeter
   CHECK ( Flaeche >= 0 ),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Korrosionsschutzbeschichtungen (
   Korrosionsschutzbeschichtungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Bauteiloberflaeche
      VARCHAR(15),
   Oberflaechenvorbereitung
      VARCHAR(15),
   Hauptbindemittel_d_Grundbesch
      VARCHAR(15),
   Hauptpigment_der_Grundbesch
      VARCHAR(15),
   Hauptbindemittel_der_Deckbesch
      VARCHAR(15),
   Hauptpigment_der_Deckbesch
      VARCHAR(15),
   Anzahl_der_Grundbeschichtungen
      INTEGER,
   Anzahl_der_Deckbeschichtungen
      INTEGER,
   Gesamtschichtdicke
      REAL, -- Mikrometer
   CHECK ( Gesamtschichtdicke >= 0 ),
   Applikation
      VARCHAR(15),
   Einbauort_Schutzbeschichtung
      VARCHAR(255),
   Dichtstoffe_fuer_Fugen_o_ae
      VARCHAR(15),
   Injizierstoffe
      VARCHAR(15),
   Ausfuehrende_Firma_Besch
      VARCHAR(80),
   Bezeichnung_Schutzbeschichtung
      VARCHAR(80),
   Einbaujahr_Korrosionsschutzb
      INTEGER, -- Jahr
   Beschichtete_Flaeche
      REAL, -- Quadratmeter
   CHECK ( Beschichtete_Flaeche >= 0 ),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Reaktionsharzgeb_Duennbelaege (
   Reaktionsharzgeb_Duennbelaege_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Bauteilnummer
      VARCHAR(15),
   Einbauort
      VARCHAR(255),
   Vorbereitung_der_Unterlage
      VARCHAR(15),
   Bindemittel_der_Grundierung
      VARCHAR(15),
   Bindemittel_1_u_2_Deckschicht
      VARCHAR(15),
   Abstreumittel_ob_Deckschicht
      VARCHAR(15),
   Gesamtdicke
      REAL, -- Millimeter
   CHECK ( Gesamtdicke >= 0 ),
   Flaeche
      REAL, -- Quadratmeter
   CHECK ( Flaeche >= 0 ),
   Einbaujahr
      INTEGER, -- Jahr
   Ausfuehrende_Firma
      VARCHAR(80),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Tunnelbeleuchtung (
   Tunnelbeleuchtung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Lichtraster
      VARCHAR(15),
   Leuchtdichte
      INTEGER, -- cd_pro_Quadratmeter
   CHECK ( Leuchtdichte >= 0 ),
   Beleuchtungsstaerke
      INTEGER, -- Lux
   CHECK ( Beleuchtungsstaerke >= 0 ),
   Beleuchtungsart
      VARCHAR(15),
   Lampenart
      VARCHAR(15),
   Bemerkungen_zur_Tunnelbeleucht
      VARCHAR(255)
)

CREATE TABLE Tunnellueftung (
   Tunnellueftung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Art_der_Tunnellueftung
      VARCHAR(15),
   Abluftkanaele
      VARCHAR(15),
   Zuluftkanaele
      VARCHAR(15),
   Abluftkamin
      VARCHAR(15),
   Luefterdecke
      VARCHAR(15),
   Bemerkungen_zur_Tunnellueftung
      VARCHAR(255)
)

CREATE TABLE Tunnelsicherheit (
   Tunnelsicherheit_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Gefahrengueter_zugelassen
      VARCHAR(15),
   Pannenbucht
      VARCHAR(15),
   Wendebucht
      VARCHAR(15),
   Ueberfahrt
      VARCHAR(15),
   Notrufstation
      VARCHAR(15),
   Automatische_Brandmeldeanlagen
      VARCHAR(15),
   Hydranten
      VARCHAR(15),
   Fluchtwege_Querstollen
      VARCHAR(15),
   Fluchtwege_Fluchtstollen
      VARCHAR(15),
   Fernsehen
      VARCHAR(15),
   Funk
      VARCHAR(15),
   Bemerkungen_zur_Tunnelsicherh
      VARCHAR(255)
)

CREATE TABLE Tunnel_Verkehrseinrichtungen (
   Tunnel_Verkehrseinrichtungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   Verkehrseinrichtung_vorhanden
      VARCHAR(15),
   Verkehrserfassung
      VARCHAR(15),
   LZA_vor_dem_Tunnel
      VARCHAR(15),
   Wechselverk_Zeich_v_d_Tunnel
      VARCHAR(15),
   Wechselverk_Zeichen_im_Tunnel
      VARCHAR(15),
   Fahrstreifensignale
      VARCHAR(15),
   Bemerkungen_zu_Verkehrseinr
      VARCHAR(255)
)

CREATE TABLE Tunnel_Zentrale_Anlagen (
   Tunnel_Zentrale_Anlagen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Laufende_Nummer
      INTEGER NOT NULL,
   gesamte_elektrische_Leistung
      INTEGER, -- Kilowatt
   CHECK ( gesamte_elektrische_Leistung >= 0 ),
   Ersatzstromversorgung
      VARCHAR(15),
   Ersatzstromversorgung_Leistung
      INTEGER, -- Kilowatt
   CHECK ( Ersatzstromversorgung_Leistung >= 0 ),
   Betriebsgebaeude
      VARCHAR(15),
   Betriebsgebaeude_Anzahl
      INTEGER,
   Lueftergebaeude
      VARCHAR(15),
   Lueftergebaeude_Anzahl
      INTEGER,
   Hebeanlage
      VARCHAR(15),
   Bemerkungen_zu_zentr_Anlagen
      VARCHAR(255)
)

